searcher library

A library providing implementations of common search algorithms.

This library offers a collection of searching methods for various data structures. Currently, it includes:

  • Binary search (src/binary.dart)
  • Jump search (src/jump.dart)
  • Linear search (src/linear.dart)

Additional search algorithms may be added in future versions.

Classes

BinarySearch
A class that provides a binary search method.
SearchResult
A class representing the result of a binary search.

Functions

jumpSearch(List list, dynamic target) Map<String, dynamic>
Performs milliseconds a jump search on a sorted list to find the index of a target element.
linearSearch(List list, dynamic target) Map<String, dynamic>
Performs a linear search on a list to find the index of a target element.